@@ -1,5 +1,7 @@
 from .cowley2022mapping_courtship_audiointerface import Cowley2022MappingCourtshipAudioInterface
-from .cowley2022mapping_courtship_behaviorinterface import Cowley2022MappingCourtshipBehaviorInterface
+from .cowley2022mapping_courtship_poseestimationinterface import Cowley2022MappingCourtshipPoseEstimationInterface
+from .cowley2022mapping_courtship_audiosegmentationinterface import Cowley2022MappingCourtshipAudioSegmentationInterface
+from .cowley2022mapping_courtship_stimuliinterface import Cowley2022MappingCourtshipStimuliInterface
 from .cowley2022mapping_imaging_behaviorinterface import Cowley2022MappingImagingBehaviorInterface
 from .cowley2022mapping_imaging_imaginginterface import Cowley2022MappingImagingMultipleInterface
 from .cowley2022mapping_imaging_segmentationinterface import Colwey2022MappingSegmentationInterface
